]> Savannah Git Hosting - gnulib.git/commitdiff
maint: spelling fixes
authorPaul Eggert <eggert@cs.ucla.edu>
Sun, 5 Feb 2012 21:42:03 +0000 (13:42 -0800)
committerPaul Eggert <eggert@cs.ucla.edu>
Sun, 5 Feb 2012 21:42:03 +0000 (13:42 -0800)
66 files changed:
NEWS
build-aux/update-copyright
doc/gnulib.texi
doc/intprops.texi
doc/pastposix-functions/usleep.texi
doc/posix-headers/stdbool.texi
doc/regex.texi
gnulib-tool
lib/argp-help.c
lib/argp-parse.c
lib/argp-version-etc.h
lib/argp.h
lib/at-func.c
lib/c-stack.c
lib/c-strstr.h
lib/c-strtod.h
lib/des.c
lib/diacrit.c
lib/expl.c
lib/fnmatch.c
lib/fnmatch_loop.c
lib/fts.c
lib/gen-uni-tables.c
lib/git-merge-changelog.c
lib/gl_anyrbtree_list1.h
lib/gl_rbtree_oset.c
lib/iconv_open.c
lib/mbiter.h
lib/mbuiter.h
lib/memchr2.c
lib/mkdir-p.c
lib/obstack.h
lib/parse-datetime.y
lib/parse-duration.h
lib/pipe-filter-ii.c
lib/pipe-filter.h
lib/poll.in.h
lib/popen.c
lib/readtokens.c
lib/regcomp.c
lib/regex.c
lib/regex_internal.c
lib/regexec.c
lib/search.in.h
lib/sleep.c
lib/strftime.c
lib/sys_socket.in.h
lib/trigl.c
lib/vasnprintf.c
lib/version-etc.h
lib/w32sock.h
m4/exponentd.m4
m4/locale-ar.m4
m4/locale-fr.m4
m4/locale-ja.m4
m4/locale-tr.m4
m4/locale-zh.m4
m4/po.m4
m4/readline.m4
m4/sig_atomic_t.m4
m4/vasnprintf.m4
tests/test-closein.sh
tests/test-lock.c
tests/test-strerror.c
tests/test-tsearch.c
tests/test-yesno.sh

diff --git a/NEWS b/NEWS
index 4ccd8f717836c3d92fecac422517eccac9b54f64..73c522bb3513b0f242a2ba61b574e631ae428322 100644 (file)
--- a/NEWS
+++ b/NEWS
@@ -543,12 +543,12 @@ Date        Modules         Changes
                             <unistd.h>.
 
 2007-06-09  xallocsa        Renamed to xmalloca. The include file "xallocsa.h"
-                            was remamed to "xmalloca.h". The function was
+                            was renamed to "xmalloca.h". The function was
                             renamed:
                               xallocsa -> xmalloca
 
 2007-06-09  allocsa         Renamed to malloca. The include file "allocsa.h"
-                            was remamed to "malloca.h". The function-like
+                            was renamed to "malloca.h". The function-like
                             macros were renamed:
                               allocsa -> malloca
                               freesa -> freea
index 30a27f2d84e20428ea3fd8c0d6396ad4e9a9f2cc..082b749d62314bfbe49165db6bfa662e0944493a 100755 (executable)
@@ -3,7 +3,7 @@ eval '(exit $?0)' && eval 'exec perl -wS -0777 -pi "$0" ${1+"$@"}'
     if 0;
 # Update an FSF copyright year list to include the current year.
 
-my $VERSION = '2012-01-27.09:18'; # UTC
+my $VERSION = '2012-02-05.21:39'; # UTC
 
 # Copyright (C) 2009-2012 Free Software Foundation, Inc.
 #
@@ -24,7 +24,7 @@ my $VERSION = '2012-01-27.09:18'; # UTC
 
 # The arguments to this script should be names of files that contain
 # copyright statements to be updated.  The copyright holder's name
-# defaults to "Free Softward Foundation, Inc." but may be changed to
+# defaults to "Free Software Foundation, Inc." but may be changed to
 # any other name by using the "UPDATE_COPYRIGHT_HOLDER" environment
 # variable.
 #
@@ -43,7 +43,7 @@ my $VERSION = '2012-01-27.09:18'; # UTC
 # A warning is printed for every file for which no copyright
 # statement is recognized.
 #
-# Each file's copyright statement must be formated correctly in
+# Each file's copyright statement must be formatted correctly in
 # order to be recognized.  For example, each of these is fine:
 #
 #   Copyright @copyright{} 1990-2005, 2007-2009 Free Software
index 1ab056f35ef41b970f850c1a11a24950def9b6e7..1581942d18169ae015a59cfa963d36d1b394e519 100644 (file)
@@ -90,7 +90,7 @@ If you need this particular \thing\, you may write to
 @node Introduction
 @chapter Introduction
 
-Gnulib is a source code library. It provides basic functionalities to
+Gnulib is a source code library. It provides basic functionality to
 programs and libraries.  Currently (as of October 2006) more than 30
 packages make use of Gnulib.
 
@@ -389,7 +389,7 @@ required module automatically, unless it is specified with option
 @code{--avoid} or it is marked as obsolete and the option
 @code{--with-obsolete} is not given.
 
-A test modules @code{foo-tests} implicity depends on the corresponding non-test
+A test modules @code{foo-tests} implicitly depends on the corresponding non-test
 module @code{foo}.  @code{foo} implicitly depends on @code{foo-tests} if the
 latter exists and if the option @code{--with-tests} has been given.
 
index 12568d92c584d21d422de9a5e42db86ba7a15ceb..8780886beed3e001eb612cf77fd3005c5b0e0680 100644 (file)
@@ -143,7 +143,7 @@ in_off_t_range (intmax_t a)
 These macros yield 1 if the corresponding C operators might not yield
 numerically correct answers due to arithmetic overflow.  They do not
 rely on undefined or implementation-defined behavior.  They expand to
-integer constant expresssions if their arguments are.  Their
+integer constant expressions if their arguments are.  Their
 implementations are simple and straightforward, but they are typically
 harder to use than the integer type overflow macros.  @xref{Integer
 Type Overflow}.
@@ -257,7 +257,7 @@ These macros yield 1 if the corresponding C operators might not yield
 numerically correct answers due to arithmetic overflow of an integer
 type.  They work correctly on all known practical hosts, and do not
 rely on undefined behavior due to signed arithmetic overflow.  They
-expand to integer constant expresssions if their arguments are.  They
+expand to integer constant expressions if their arguments are.  They
 are easier to use than the integer range overflow macros
 (@pxref{Integer Range Overflow}).
 
index 468ec667025659bc42fef90969ef1e64880e6ba7..d15e1e02de9c7e8e2e91a11b6aa1f10c37c9a799 100644 (file)
@@ -14,7 +14,7 @@ second, as allowed by POSIX:
 mingw.
 @item
 This function is missing on some platforms.  However, the replacement
-is designed to be lightweight, and may round to the neareset second;
+is designed to be lightweight, and may round to the nearest second;
 use @code{select} or @code{nanosleep} if better resolution is needed:
 IRIX 5.3, Solaris 2.4, older mingw, MSVC 9, BeOS.
 @end itemize
index de27763bc5d18586a20e7c196e00905dc99f80f8..50afbd41f8aebc23ea3ecb514cfe5c56e728d86b 100644 (file)
@@ -29,7 +29,7 @@ should use @samp{unsigned int foo : 1;} rather than @samp{bool foo : 1;}.
 @item
 Casts and automatic conversions to @samp{bool} don't test against the
 zero value or the null pointer, as they should.  Such casts should only
-be used if the casted value is known to be equal to 0 or 1.
+be used if the value is known to be equal to 0 or 1.
 @item
 You cannot assume that casting a floating point literal to @samp{bool} will
 result in a constant expression.
index 6601c6bf11775a4cd57299bc3b344abd45b2dfc1..3c31db3b5da30f1cf9598f1ed99679ca7c1ce3d7 100644 (file)
@@ -1853,7 +1853,7 @@ matching or searching with the pattern buffer.
 @node Using Registers
 @subsection Using Registers
 
-A group in a regular expression can match a (posssibly empty) substring
+A group in a regular expression can match a (possibly empty) substring
 of the string that regular expression as a whole matched.  The matcher
 remembers the beginning and end of the substring matched by
 each group.
index de8f6fea79fd2d6612aceb6ecb3223f1d7a31eb4..3c895ac6900399322f84eb1315aeb58a9d35fa1b 100755 (executable)
@@ -5558,7 +5558,7 @@ func_create_testdir ()
   # its dependencies.
   saved_inctests="$inctests"
   # When computing transitive closures, don't consider $module to depend on
-  # $module-tests. Need this becauses tests are implicitly GPL and may depend
+  # $module-tests. Need this because tests are implicitly GPL and may depend
   # on GPL modules - therefore we don't want a warning in this case.
   inctests=""
   for requested_module in $specified_modules; do
index 6d2903e5070dc3d16419476d40251d56dd4cd5dc..a126acb9bab2e4802c70851f334c9e679fb61f89 100644 (file)
@@ -1,4 +1,4 @@
-/* Hierarchial argument parsing help output
+/* Hierarchical argument parsing help output
    Copyright (C) 1995-2005, 2007, 2009-2012 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
    Written by Miles Bader <miles@gnu.ai.mit.edu>.
@@ -154,7 +154,7 @@ ARGP_HELP_FMT: %s value is less than or equal to %s"),
   uparams.valid = 1;
 }
 
-/* Read user options from the environment, and fill in UPARAMS appropiately. */
+/* Read user options from the environment, and fill in UPARAMS appropriately. */
 static void
 fill_in_uparams (const struct argp_state *state)
 {
@@ -277,11 +277,11 @@ fill_in_uparams (const struct argp_state *state)
      -xARG, -yARG, --long1=ARG, --long2=ARG        Documentation...
 
    Where ARG will be omitted if there's no argument, for this option, or
-   will be surrounded by "[" and "]" appropiately if the argument is
-   optional.  The documentation string is word-wrapped appropiately, and if
+   will be surrounded by "[" and "]" appropriately if the argument is
+   optional.  The documentation string is word-wrapped appropriately, and if
    the list of options is long enough, it will be started on a separate line.
    If there are no short options for a given option, the first long option is
-   indented slighly in a way that's supposed to make most long options appear
+   indented slightly in a way that's supposed to make most long options appear
    to be in a separate column.
 
    For example, the following output (from ps):
@@ -753,7 +753,7 @@ hol_entry_cmp (const struct hol_entry *entry1,
   if (entry1->cluster != entry2->cluster)
     {
       /* The entries are not within the same cluster, so we can't compare them
-         directly, we have to use the appropiate clustering level too.  */
+         directly, we have to use the appropriate clustering level too.  */
       if (! entry1->cluster)
         /* ENTRY1 is at the "base level", not in a cluster, so we have to
            compare it's group number with that of the base cluster in which
@@ -1023,7 +1023,7 @@ filter_doc (const char *doc, int key, const struct argp *argp,
     return doc;
 }
 
-/* Prints STR as a header line, with the margin lines set appropiately, and
+/* Prints STR as a header line, with the margin lines set appropriately, and
    notes the fact that groups should be separated with a blank line.  ARGP is
    the argp that should dictate any user doc filtering to take place.  Note
    that the previous wrap margin isn't restored, but the left margin is reset
@@ -1480,7 +1480,7 @@ argp_args_usage (const struct argp *argp, const struct argp_state *state,
 }
 \f
 /* Print the documentation for ARGP to STREAM; if POST is false, then
-   everything preceeding a '\v' character in the documentation strings (or
+   everything preceding a '\v' character in the documentation strings (or
    the whole string, for those with none) is printed, otherwise, everything
    following the '\v' character (nothing for strings without).  Each separate
    bit of documentation is separated a blank line, and if PRE_BLANK is true,
@@ -1579,7 +1579,7 @@ argp_doc (const struct argp *argp, const struct argp_state *state,
 }
 \f
 /* Output a usage message for ARGP to STREAM.  If called from
-   argp_state_help, STATE is the relevent parsing state.  FLAGS are from the
+   argp_state_help, STATE is the relevant parsing state.  FLAGS are from the
    set ARGP_HELP_*.  NAME is what to use wherever a "program name" is
    needed. */
 static void
index 09558b4f8fb346176f2e7dc009ba5411519d95c1..3b411d407b292474d45cbc468754d87be1d621e2 100644 (file)
@@ -1,4 +1,4 @@
-/* Hierarchial argument parsing, layered over getopt
+/* Hierarchical argument parsing, layered over getopt
    Copyright (C) 1995-2000, 2002-2004, 2009-2012 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
    Written by Miles Bader <miles@gnu.ai.mit.edu>.
@@ -204,7 +204,7 @@ struct group
      particular short options is from.  */
   char *short_end;
 
-  /* The number of non-option args sucessfully handled by this parser.  */
+  /* The number of non-option args successfully handled by this parser.  */
   unsigned args_processed;
 
   /* This group's parser's parent's group.  */
@@ -386,7 +386,7 @@ convert_options (const struct argp *argp,
   return group;
 }
 
-/* Find the merged set of getopt options, with keys appropiately prefixed. */
+/* Find the merged set of getopt options, with keys appropriately prefixed. */
 static void
 parser_convert (struct parser *parser, const struct argp *argp, int flags)
 {
index 94cf42fc32d9ee2be83ec6774aff49eb5b84267f..951720141136a352da09fbf7c962ac2a997ae594 100644 (file)
@@ -27,7 +27,7 @@ extern "C" {
    given.
 
    If NAME is NULL, the package name (as given by the PACKAGE macro)
-   is asumed to be the name of the program.
+   is assumed to be the name of the program.
 
    This function is intended to be called before argp_parse().
 */
index f9f266e3e1da105c674a5abdd9021ead7c36a146..c0c68a61e74af32f65dcdf045357db05a9690a20 100644 (file)
@@ -1,4 +1,4 @@
-/* Hierarchial argument parsing, layered over getopt.
+/* Hierarchical argument parsing, layered over getopt.
    Copyright (C) 1995-1999, 2003-2012 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
    Written by Miles Bader <miles@gnu.ai.mit.edu>.
@@ -278,7 +278,7 @@ struct argp
 };
 
 /* Possible KEY arguments to a help filter function.  */
-#define ARGP_KEY_HELP_PRE_DOC   0x2000001 /* Help text preceeding options. */
+#define ARGP_KEY_HELP_PRE_DOC   0x2000001 /* Help text preceding options. */
 #define ARGP_KEY_HELP_POST_DOC  0x2000002 /* Help text following options. */
 #define ARGP_KEY_HELP_HEADER    0x2000003 /* Option header string. */
 #define ARGP_KEY_HELP_EXTRA     0x2000004 /* After all other documentation;
@@ -506,7 +506,7 @@ extern void __argp_help (const struct argp *__restrict __argp,
    parsing routine (thus taking an argp_state structure as the first
    argument).  They may or may not print an error message and exit, depending
    on the flags in STATE -- in any case, the caller should be prepared for
-   them *not* to exit, and should return an appropiate error after calling
+   them *not* to exit, and should return an appropriate error after calling
    them.  [argp_usage & argp_error should probably be called argp_state_...,
    but they're used often enough that they should be short]  */
 
index 688125f1d78a007c6c311cc6b75bdcea5a149151..b25bc4d8191ad14874835c5623c2fe5680b88e0f 100644 (file)
@@ -51,7 +51,7 @@
 
 /* Call AT_FUNC_F1 to operate on FILE, which is in the directory
    open on descriptor FD.  If AT_FUNC_USE_F1_COND is defined to a value,
-   AT_FUNC_POST_FILE_PARAM_DECLS must inlude a parameter named flag;
+   AT_FUNC_POST_FILE_PARAM_DECLS must include a parameter named flag;
    call AT_FUNC_F2 if FLAG is 0 or fail if FLAG contains more bits than
    AT_FUNC_USE_F1_COND.  Return int and fail with -1 unless AT_FUNC_RESULT
    or AT_FUNC_FAIL are defined.  If possible, do it without changing the
index 33a8251c75b2b8fef96e41e422f698ccae39204b..def2bb71194bd680b7896195e98221192edf4e5b 100644 (file)
@@ -237,7 +237,7 @@ segv_handler (int signo, siginfo_t *info,
 
      Note that although both Linux and Solaris provide
      sigaltstack, SA_ONSTACK, and SA_SIGINFO, currently only
-     Solaris satisfies the XSI heueristic.  This is because
+     Solaris satisfies the XSI heuristic.  This is because
      Solaris populates uc_stack with the details of the
      interrupted stack, while Linux populates it with the details
      of the current stack.  */
index f934593ea5665a0c5f09d6615d4cb25f46f9bcb7..b5f8a649d93ea32f096404df1bee0fd668c9ebd5 100644 (file)
@@ -33,7 +33,7 @@ extern "C" {
         [this restriction is needed because of BIG5, BIG5-HKSCS, GBK, GB18030,
          Shift_JIS, JOHAB], and
      3. does not consist entirely of decimal digits, or has at least length 4
-        [this restricion is needed because of GB18030].
+        [this restriction is needed because of GB18030].
    This function is also safe to be called, even in a multibyte locale, if
    HAYSTACK and NEEDLE are known to both consist solely of printable ASCII
    characters excluding '\\' and '~'.  */
index 77971548110b109933f4a397d388230b84ab75fa..e3b8dc4bca12e3beb02aa8f1bea5954a802c928f 100644 (file)
@@ -20,7 +20,7 @@
    accepting only the ASCII digits '0'..'9', and only '.' as decimal point
    character.
    If ENDPTR is not NULL, set *ENDPTR to point to the first byte beyond the
-   parsed number or to NPTR if the string does not start with a parseable
+   parsed number or to NPTR if the string does not start with a parsable
    number.
    Return value:
    - If successful, return the value as a double or 'long double',
index 3152dbec1f1e747d9914b177bfd51d930fbcaac3..ea86785cd7ef4d15ddfe14f78b62b1a4b15b769e 100644 (file)
--- a/lib/fts.c
+++ b/lib/fts.c
@@ -704,7 +704,7 @@ leaf_optimization_applies (int dir_fd)
 
   switch (fs_buf.f_type)
     {
-      /* List here the file system types that lack useable dirent.d_type
+      /* List here the file system types that lack usable dirent.d_type
          info, yet for which the optimization does apply.  */
     case S_MAGIC_REISERFS:
       return true;
index ded8159136fa470452574a54accb59e4bddd0e64..1ea6ecc16a8b0646c88de2721c9f20e6e4f59962 100644 (file)
@@ -92,7 +92,7 @@ fill_attribute (unsigned int i,
       exit (1);
     }
   if (strcmp (field2, "Cs") == 0)
-    /* Surrogates are UTF-16 artefacts, not real characters. Ignore them.  */
+    /* Surrogates are UTF-16 artifacts, not real characters. Ignore them.  */
     return;
   uni = &unicode_attributes[i];
   /* Copy the strings.  */
@@ -5698,7 +5698,7 @@ output_tables (const char *filename, const char *version)
   fprintf (stream, "END LC_IDENTIFICATION\n");
   fprintf (stream, "\n");
 
-  /* Verifications. */
+  /* Verification. */
   for (ch = 0; ch < 0x110000; ch++)
     {
       /* toupper restriction: "Only characters specified for the keywords
index aac30328ad81ea602c1f14d452d0743b76da1bbc..500f55bf089efdf408b8eee74cdf0fdb900cee31 100644 (file)
@@ -958,7 +958,7 @@ static const struct option long_options[] =
   { NULL, 0, NULL, 0 }
 };
 
-/* Print a usage mesage and exit.  */
+/* Print a usage message and exit.  */
 static void
 usage (int status)
 {
index 7a22520e37c61f7e5524ce9f5efc85e9432efc97..251ae8078965f806878d286ddbf246c42f05b232 100644 (file)
@@ -27,7 +27,7 @@
    Let's call this the "black-height" bh of the tree.  It follows that every
    such path contains exactly bh black and between 0 and bh red nodes.  (The
    extreme cases are a path containing only black nodes, and a path colored
-   alternatingly black-red-black-red-...-black-red.)  The height of the tree
+   alternately black-red-black-red-...-black-red.)  The height of the tree
    therefore is >= bh, <= 2*bh.
  */
 
index 2e21573032669faa02564c9b273660e833c76de7..a94c14d17655025fcc49ce50aba7fb644eee0751 100644 (file)
@@ -32,7 +32,7 @@
    Let's call this the "black-height" bh of the tree.  It follows that every
    such path contains exactly bh black and between 0 and bh red nodes.  (The
    extreme cases are a path containing only black nodes, and a path colored
-   alternatingly black-red-black-red-...-black-red.)  The height of the tree
+   alternately black-red-black-red-...-black-red.)  The height of the tree
    therefore is >= bh, <= 2*bh.
  */
 
index 70e2856d993dbf79e4743447d1bac880521a570a..bf2a492bad39182583f92027f92fbc7808b98540 100644 (file)
@@ -57,7 +57,7 @@ rpl_iconv_open (const char *tocode, const char *fromcode)
      iconv() to these encoding inserts a BOM, which is wrong.
      We do not need to handle conversion between arbitrary encodings and
      UTF-{16,32}{BE,LE}, because the 'striconveh' module implements two-step
-     conversion throough UTF-8.
+     conversion through UTF-8.
      The _ICONV_* constants are chosen to be disjoint from any iconv_t
      returned by the system's iconv_open() functions.  Recall that iconv_t
      is a scalar type.  */
index 5d5e69865001680fae214dd80fd676fd827d7d40..5419a67abc248505741e0f85eaba48ecbfcf7546 100644 (file)
@@ -47,9 +47,9 @@
      initializes the iterator, starting at startptr and crossing length bytes.
 
    mbi_avail (iter)
-     returns true if there are more multibyte chracters available before
+     returns true if there are more multibyte characters available before
      the end of string is reached. In this case, mbi_cur (iter) is
-     initialized to the next multibyte chracter.
+     initialized to the next multibyte character.
 
    mbi_advance (iter)
      advances the iterator by one multibyte character.
index 86f9fd6b955f2a13e2d70098467782091866cc0f..44b617371ba7ed12f27759fec14738442d5246ff 100644 (file)
@@ -55,9 +55,9 @@
      initializes the iterator, starting at startptr.
 
    mbui_avail (iter)
-     returns true if there are more multibyte chracters available before
+     returns true if there are more multibyte characters available before
      the end of string is reached. In this case, mbui_cur (iter) is
-     initialized to the next multibyte chracter.
+     initialized to the next multibyte character.
 
    mbui_advance (iter)
      advances the iterator by one multibyte character.
index b1c61df1a5272cdf8c04ee7fc830c9a442cf2c09..b8816a5959d94d760585ed482ec1f90fd1a9421a 100644 (file)
@@ -125,7 +125,7 @@ memchr2 (void const *s, int c1_in, int c2_in, size_t n)
      significant bytes (positions j+1..3), but it does not matter since we
      already have a non-zero bit at position 8*j+7.
 
-     Similary, we compute tmp2 =
+     Similarly, we compute tmp2 =
        ((longword2 - repeated_one) & ~longword2) & (repeated_one << 7).
 
      The test whether any byte in longword1 or longword2 is zero is equivalent
index 547b5cf4341cf670b9f0af5403471c2ce81465d1..58ee45bf2b7a751bf8202edcf46bbd8ecf1bec33 100644 (file)
@@ -115,7 +115,7 @@ make_dir_parents (char *dir,
       if (0 <= prefix_len)
         {
           /* If the ownership might change, or if the directory will be
-             writeable to other users and its special mode bits may
+             writable to other users and its special mode bits may
              change after the directory is created, create it with
              more restrictive permissions at first, so unauthorized
              users cannot nip in before the directory is ready.  */
index b7d2404a16e451d00086f49b40dad7e8628cd591..6a44b44b97f3619a8b66477ed09b3270e7ab4ebb 100644 (file)
@@ -122,7 +122,7 @@ Summary:
 
 #define __BPTR_ALIGN(B, P, A) ((B) + (((P) - (B) + (A)) & ~(A)))
 
-/* Similiar to _BPTR_ALIGN (B, P, A), except optimize the common case
+/* Similar to _BPTR_ALIGN (B, P, A), except optimize the common case
    where pointers can be converted to integers, aligned as integers,
    and converted back again.  If PTR_INT_TYPE is narrower than a
    pointer (e.g., the AS/400), play it safe and compute the alignment
index 01d71051c40fa73a39b7ae73a68e04ff5705689c..67669f6319ceda0c6158cb03d99bb6253801a05c 100644 (file)
@@ -204,7 +204,7 @@ typedef struct
   size_t times_seen;
   size_t zones_seen;
 
-  /* Table of local time zone abbrevations, terminated by a null entry.  */
+  /* Table of local time zone abbreviations, terminated by a null entry.  */
   table local_time_zone_table[3];
 } parser_control;
 
@@ -1394,7 +1394,7 @@ parse_datetime (struct timespec *result, char const *p,
       && ! strcmp (pc.local_time_zone_table[0].name,
                    pc.local_time_zone_table[1].name))
     {
-      /* This locale uses the same abbrevation for standard and
+      /* This locale uses the same abbreviation for standard and
          daylight times.  So if we see that abbreviation, we don't
          know whether it's daylight time.  */
       pc.local_time_zone_table[0].value = -1;
index 3f7753006036666b9ee4a7b9b588f8f0f56a20a3..caefb759b4cdab5b9a5269cbc46f3df3bf615533 100644 (file)
@@ -31,7 +31,7 @@
   the string may contain:  NNN Y NNN M NNN W NNN d NNN h NNN m NNN s
   This represents NNN years, NNN months, NNN weeks, NNN days, NNN hours,
     NNN minutes and NNN seconds.
-  The embeded white space is optional.
+  The embedded white space is optional.
   These terms must appear in this order.
   Case is significant:  'M' is months and 'm' is minutes.
   The final "s" is optional.
index 1e1d61e90d50462520c94f9e792badb2a4493b42..dd57f0a011f7d2661d6290f729c629b9c53a7634 100644 (file)
@@ -348,7 +348,7 @@ pipe_filter_ii_execute (const char *progname,
             if (buf != NULL)
               {
                 /* Writing to a pipe in non-blocking mode is tricky: The
-                   write() call may fail with EAGAIN, simply because suffcient
+                   write() call may fail with EAGAIN, simply because sufficient
                    space is not available in the pipe. See POSIX:2008
                    <http://pubs.opengroup.org/onlinepubs/9699919799/functions/write.html>.
                    This happens actually on AIX and IRIX, when bufsize >= 8192
index 1bea48fc9fc096494ea36f2fb72b9cf85587e296..49e83a3489231a4f32322fa832273cb62acfc3d4 100644 (file)
@@ -119,7 +119,7 @@ typedef void (*done_read_fn) (void *data_read, size_t num_bytes_read,
    true, otherwise return 127.
    Callback arguments are as described above.
 
-   Data is alternatingly written to the subprocess, through the functions
+   Data is alternately written to the subprocess, through the functions
    prepare_write and done_write, and read from the subprocess, through the
    functions prepare_read and done_read.
 
index 16a9c92d6b461f8069de07c459e6e79d5c8116fa..90d4e8cda5931acae5b604d56d540bbfe00eb15a 100644 (file)
@@ -45,7 +45,7 @@
 /* fake a poll(2) environment */
 # define POLLIN      0x0001      /* any readable data available   */
 # define POLLPRI     0x0002      /* OOB/Urgent readable data      */
-# define POLLOUT     0x0004      /* file descriptor is writeable  */
+# define POLLOUT     0x0004      /* file descriptor is writable   */
 # define POLLERR     0x0008      /* some poll error occurred      */
 # define POLLHUP     0x0010      /* file descriptor was "hung up" */
 # define POLLNVAL    0x0020      /* requested events "invalid"    */
index 1460e9edbb818a9bdea37a42fb242d1b8b44f706..590f9843bf402b7d91c7b415b7ddd46af70c7802 100644 (file)
@@ -59,7 +59,7 @@ rpl_popen (const char *filename, const char *mode)
      the fd leaks into subsequent popen calls.  We could work around
      this by maintaining a list of all fd's opened by popen, and
      temporarily marking them cloexec around the real popen call, but
-     we would also have to override pclose, and the bookkeepping seems
+     we would also have to override pclose, and the bookkeeping seems
      extreme given that cygwin 1.7 no longer has the bug.  */
   FILE *result;
   int cloexec0 = fcntl (STDIN_FILENO, F_GETFD);
index dac1b6c52273877822c4e1729f97f476f54cf99e..705a62b90cc1f279623d1ca50e99a4c492ebc2fc 100644 (file)
@@ -18,7 +18,7 @@
 
    Written by Jim Meyering. */
 
-/* This almost supercedes xreadline stuff -- using delim="\n"
+/* This almost supersedes xreadline stuff -- using delim="\n"
    gives the same functionality, except that these functions
    would never return empty lines. */
 
index 3398adb8b838e0b3c9edc838ed964449ab69b92c..89940ce11cc1c7e2138fd851f168dbba6ce219c9 100644 (file)
@@ -2092,7 +2092,7 @@ peek_token_bracket (re_token_t *token, re_string_t *input, reg_syntax_t syntax)
 
 /* Entry point of the parser.
    Parse the regular expression REGEXP and return the structure tree.
-   If an error is occured, ERR is set by error code, and return NULL.
+   If an error occurs, ERR is set by error code, and return NULL.
    This function build the following tree, from regular expression <reg_exp>:
           CAT
           / \
@@ -2615,7 +2615,7 @@ parse_dup_op (bin_tree_t *elem, re_string_t *regexp, re_dfa_t *dfa,
      Build the range expression which starts from START_ELEM, and ends
      at END_ELEM.  The result are written to MBCSET and SBCSET.
      RANGE_ALLOC is the allocated size of mbcset->range_starts, and
-     mbcset->range_ends, is a pointer argument sinse we may
+     mbcset->range_ends, is a pointer argument since we may
      update it.  */
 
 static reg_errcode_t
@@ -2781,8 +2781,8 @@ parse_bracket_exp (re_string_t *regexp, re_dfa_t *dfa, re_token_t *token,
   const int32_t *symb_table;
   const unsigned char *extra;
 
-  /* Local function for parse_bracket_exp used in _LIBC environement.
-     Seek the collating symbol entry correspondings to NAME.
+  /* Local function for parse_bracket_exp used in _LIBC environment.
+     Seek the collating symbol entry corresponding to NAME.
      Return the index of the symbol in the SYMB_TABLE.  */
 
   auto inline int32_t
@@ -2885,11 +2885,11 @@ parse_bracket_exp (re_string_t *regexp, re_dfa_t *dfa, re_token_t *token,
       return UINT_MAX;
     }
 
-  /* Local function for parse_bracket_exp used in _LIBC environement.
+  /* Local function for parse_bracket_exp used in _LIBC environment.
      Build the range expression which starts from START_ELEM, and ends
      at END_ELEM.  The result are written to MBCSET and SBCSET.
      RANGE_ALLOC is the allocated size of mbcset->range_starts, and
-     mbcset->range_ends, is a pointer argument sinse we may
+     mbcset->range_ends, is a pointer argument since we may
      update it.  */
 
   auto inline reg_errcode_t
@@ -2969,11 +2969,11 @@ parse_bracket_exp (re_string_t *regexp, re_dfa_t *dfa, re_token_t *token,
       return REG_NOERROR;
     }
 
-  /* Local function for parse_bracket_exp used in _LIBC environement.
+  /* Local function for parse_bracket_exp used in _LIBC environment.
      Build the collating element which is represented by NAME.
      The result are written to MBCSET and SBCSET.
      COLL_SYM_ALLOC is the allocated size of mbcset->coll_sym, is a
-     pointer argument sinse we may update it.  */
+     pointer argument since we may update it.  */
 
   auto inline reg_errcode_t
   __attribute ((always_inline))
@@ -3413,7 +3413,7 @@ parse_bracket_symbol (bracket_elem_t *elem, re_string_t *regexp,
      Build the equivalence class which is represented by NAME.
      The result are written to MBCSET and SBCSET.
      EQUIV_CLASS_ALLOC is the allocated size of mbcset->equiv_classes,
-     is a pointer argument sinse we may update it.  */
+     is a pointer argument since we may update it.  */
 
 static reg_errcode_t
 #ifdef RE_ENABLE_I18N
@@ -3449,7 +3449,7 @@ build_equiv_class (bitset_t sbcset, const unsigned char *name)
        /* This isn't a valid character.  */
        return REG_ECOLLATE;
 
-      /* Build single byte matcing table for this equivalence class.  */
+      /* Build single byte matching table for this equivalence class.  */
       char_buf[1] = (unsigned char) '\0';
       len = weights[idx1 & 0xffffff];
       for (ch = 0; ch < SBC_MAX; ++ch)
@@ -3509,7 +3509,7 @@ build_equiv_class (bitset_t sbcset, const unsigned char *name)
      Build the character class which is represented by NAME.
      The result are written to MBCSET and SBCSET.
      CHAR_CLASS_ALLOC is the allocated size of mbcset->char_classes,
-     is a pointer argument sinse we may update it.  */
+     is a pointer argument since we may update it.  */
 
 static reg_errcode_t
 #ifdef RE_ENABLE_I18N
index 3b219555aa365042f7df17feddd1259615885590..edc85f34b49331c4e5443921f02b744122e28d04 100644 (file)
@@ -19,7 +19,7 @@
 
 #include <config.h>
 
-/* Make sure noone compiles this code with a C++ compiler.  */
+/* Make sure no one compiles this code with a C++ compiler.  */
 #if defined __cplusplus && defined _LIBC
 # error "This is C code, use a C compiler"
 #endif
index e7c9b6bd9531c7990a111694bb02b69fb1cd92e7..4fb98351b746152ada78be829de59de66b26fa25 100644 (file)
@@ -1614,7 +1614,7 @@ free_state (re_dfastate_t *state)
   re_free (state);
 }
 
-/* Create the new state which is independ of contexts.
+/* Create the new state which is independent of contexts.
    Return the new state if succeeded, otherwise return NULL.  */
 
 static re_dfastate_t *
index aa8e52428273e97589a3282dba18456929c00c7f..5f12de91ee6a14405dff817d7fad6f5755cf1c2f 100644 (file)
@@ -921,7 +921,7 @@ re_search_internal (const regex_t *preg,
            goto free_return;
        }
 
-      /* At last, add the offset to the each registers, since we slided
+      /* At last, add the offset to each register, since we slid
         the buffers so that we could assume that the matching starts
         from 0.  */
       for (reg_idx = 0; reg_idx < nmatch; ++reg_idx)
@@ -1105,7 +1105,7 @@ acquire_init_state_context (reg_errcode_t *err, const re_match_context_t *mctx,
    FL_LONGEST_MATCH means we want the POSIX longest matching.
    If P_MATCH_FIRST is not NULL, and the match fails, it is set to the
    next place where we may want to try matching.
-   Note that the matcher assume that the maching starts from the current
+   Note that the matcher assumes that the matching starts from the current
    index of the buffer.  */
 
 static Idx
@@ -2456,7 +2456,7 @@ find_recover_state (reg_errcode_t *err, re_match_context_t *mctx)
 /* From the node set CUR_NODES, pick up the nodes whose types are
    OP_OPEN_SUBEXP and which have corresponding back references in the regular
    expression. And register them to use them later for evaluating the
-   correspoding back references.  */
+   corresponding back references.  */
 
 static reg_errcode_t
 internal_function
@@ -3387,7 +3387,7 @@ build_trtable (const re_dfa_t *dfa, re_dfastate_t *state)
   dests_node = dests_alloc->dests_node;
   dests_ch = dests_alloc->dests_ch;
 
-  /* Initialize transiton table.  */
+  /* Initialize transition table.  */
   state->word_trtable = state->trtable = NULL;
 
   /* At first, group all nodes belonging to 'state' into several
index d146967b0559944dc829ab3dc60cd80e63aec319..79a462407f6228c914e4bfead7ebd831e83c0c49 100644 (file)
@@ -158,7 +158,7 @@ _GL_CXXALIASWARN (tdelete);
        and after the right subtree traversal,
      - for leaf nodes: once.
    The arguments passed to ACTION are:
-     1. the node; it can be casted to a 'const void * const *', i.e. into a
+     1. the node; it can be cast to a 'const void * const *', i.e. into a
         pointer to the key,
      2. an indicator which visit of the node this is,
      3. the level of the node in the tree (0 for the root).  */
index e5d329906c5b701b647fece0cc7c971c5b1f90c9..9a4b9400cc195e9ae2cc1f999e8fc4d66be875e3 100644 (file)
@@ -35,7 +35,7 @@ sleep (unsigned int seconds)
   unsigned int remaining;
 
   /* Sleep for 1 second many times, because
-       1. Sleep is not interruptiple by Ctrl-C,
+       1. Sleep is not interruptible by Ctrl-C,
        2. we want to avoid arithmetic overflow while multiplying with 1000.  */
   for (remaining = seconds; remaining > 0; remaining--)
     Sleep (1000);
index 3b7f8437dd754eb745507d95b02f3ae65f5262af..c7b8eb5ef7e5619a5b735fee0650f240898e4c98 100644 (file)
@@ -40,7 +40,7 @@
 extern char *tzname[];
 #endif
 
-/* Do multibyte processing if multibytes are supported, unless
+/* Do multibyte processing if multibyte encodings are supported, unless
    multibyte sequences are safe in formats.  Multibyte sequences are
    safe if they cannot contain byte sequences that look like format
    conversion specifications.  The multibyte encodings used by the
index dd638adbafa5010ca093b35f0a1ba311d8f532ac..b8625adf7507820b608c39684ecd1655ad36ca42 100644 (file)
@@ -143,7 +143,7 @@ struct sockaddr_storage
    that you can influence which definitions you get by setting the
    WINVER symbol before including these two files.  For example,
    getaddrinfo is only available if _WIN32_WINNT >= 0x0501 (that
-   symbol is set indiriectly through WINVER).  You can set this by
+   symbol is set indirectly through WINVER).  You can set this by
    adding AC_DEFINE(WINVER, 0x0501) to configure.ac.  Note that your
    code may not run on older Windows releases then.  My Windows 2000
    box was not able to run the code, for example.  The situation is
index ebb1590105680f3e7b04407e4dadf9fc2bbe2ed7..c5f298446c3df487490742e1701408ce09d7a78f 100644 (file)
@@ -456,7 +456,7 @@ kernel_rem_pio2 (double *x, double *y, int e0, int nx, int prec,
 
   jz = jk;
 recompute:
-  /* distill q[] into iq[] reversingly */
+  /* distill q[] into iq[] in reverse order */
   for (i = 0, j = jz, z = q[jz]; j > 0; i++, j--)
     {
       fw = (double) ((int) (twon24 * z));
index afbff4fd065d0ecaceed29f248471d124578a376..ccd20282c4c93bfadca284484a7227e0679d2607 100644 (file)
@@ -2814,7 +2814,7 @@ VASNPRINTF (DCHAR_T *resultbuf, size_t *lengthp,
                   if (has_width)
                     {
 #  if ENABLE_UNISTDIO
-                      /* Outside POSIX, it's preferrable to compare the width
+                      /* Outside POSIX, it's preferable to compare the width
                          against the number of _characters_ of the converted
                          value.  */
                       w = DCHAR_MBSNLEN (result + length, characters);
@@ -5417,7 +5417,7 @@ VASNPRINTF (DCHAR_T *resultbuf, size_t *lengthp,
                       {
                         size_t w;
 # if ENABLE_UNISTDIO
-                        /* Outside POSIX, it's preferrable to compare the width
+                        /* Outside POSIX, it's preferable to compare the width
                            against the number of _characters_ of the converted
                            value.  */
                         w = DCHAR_MBSNLEN (result + length, count);
index c62704cd42e9d4e7b5224f6ba1042dd4806c01aa..5548c023c3b8c34b4eb6be7c20840724f7d80e7c 100644 (file)
@@ -37,7 +37,7 @@ extern const char version_etc_copyright[];
    standard way: command and package names, package version, followed
    by a short GPLv3+ notice and a list of up to 10 author names.
 
-   If COMMAND_NAME is NULL, the PACKAGE is asumed to be the name of
+   If COMMAND_NAME is NULL, the PACKAGE is assumed to be the name of
    the program.  The formats are therefore:
 
    PACKAGE VERSION
index 9e38a7bebba487a20d438d14ccb19c6b91cd79d7..ef0b5937e1f8cdfff6f98f8528c9ec01d24a0c32 100644 (file)
@@ -1,4 +1,4 @@
-/* w32sock.h --- internal auxilliary functions for Windows socket functions
+/* w32sock.h --- internal auxiliary functions for Windows socket functions
 
    Copyright (C) 2008-2012 Free Software Foundation, Inc.
 
index 48df999ab5695450459eeb1072b9ed1ffb4255ba..0ae4ccfac936a5a792c900c0ce1912715d6faf14 100644 (file)
@@ -1,4 +1,4 @@
-# exponentd.m4 serial 2
+# exponentd.m4 serial 3
 dnl Copyright (C) 2007-2008, 2010-2012 Free Software Foundation, Inc.
 dnl This file is free software; the Free Software Foundation
 dnl gives unlimited permission to copy and/or distribute it,
@@ -80,7 +80,8 @@ int main ()
           dnl different sets of instructions: The older FPA instructions assume
           dnl that they are stored in big-endian word order, while the words
           dnl (like integer types) are stored in little-endian byte order.
-          dnl The newer VFP instructions assume little-endian order consistenly.
+          dnl The newer VFP instructions assume little-endian order
+          dnl consistently.
           AC_EGREP_CPP([mixed_endianness], [
 #if defined arm || defined __arm || defined __arm__
   mixed_endianness
index 2d2a6c68b9242cc0b6127c71aff0eaacf99f16dd..8978e9984363b284be03b3b29f8c37e4d320a1f7 100644 (file)
@@ -1,4 +1,4 @@
-# locale-ar.m4 serial 4
+# locale-ar.m4 serial 5
 dnl Copyright (C) 2003, 2005-2012 Free Software Foundation, Inc.
 dnl This file is free software; the Free Software Foundation
 dnl gives unlimited permission to copy and/or distribute it,
@@ -28,7 +28,7 @@ int main () {
 #if (defined _WIN32 || defined __WIN32__) && !defined __CYGWIN__
   /* On native Windows, setlocale(category, "") looks at the system settings,
      not at the environment variables.  Also, when an encoding suffix such
-     as ".65001" or ".54936" is speficied, it succeeds but sets the LC_CTYPE
+     as ".65001" or ".54936" is specified, it succeeds but sets the LC_CTYPE
      category of the locale to "C".  */
   if (setlocale (LC_ALL, getenv ("LC_ALL")) == NULL
       || strcmp (setlocale (LC_CTYPE, NULL), "C") == 0)
index 11056b8cc652aa9ace053228049bf01aa3a55343..04d801f23e4c738da89017cee0e94fad96e64377 100644 (file)
@@ -1,4 +1,4 @@
-# locale-fr.m4 serial 15
+# locale-fr.m4 serial 16
 dnl Copyright (C) 2003, 2005-2012 Free Software Foundation, Inc.
 dnl This file is free software; the Free Software Foundation
 dnl gives unlimited permission to copy and/or distribute it,
@@ -28,7 +28,7 @@ int main () {
 #if (defined _WIN32 || defined __WIN32__) && !defined __CYGWIN__
   /* On native Windows, setlocale(category, "") looks at the system settings,
      not at the environment variables.  Also, when an encoding suffix such
-     as ".65001" or ".54936" is speficied, it succeeds but sets the LC_CTYPE
+     as ".65001" or ".54936" is specified, it succeeds but sets the LC_CTYPE
      category of the locale to "C".  */
   if (setlocale (LC_ALL, getenv ("LC_ALL")) == NULL
       || strcmp (setlocale (LC_CTYPE, NULL), "C") == 0)
@@ -156,7 +156,7 @@ int main () {
 # if (defined _WIN32 || defined __WIN32__) && !defined __CYGWIN__
   /* On native Windows, setlocale(category, "") looks at the system settings,
      not at the environment variables.  Also, when an encoding suffix such
-     as ".65001" or ".54936" is speficied, it succeeds but sets the LC_CTYPE
+     as ".65001" or ".54936" is specified, it succeeds but sets the LC_CTYPE
      category of the locale to "C".  */
   if (setlocale (LC_ALL, getenv ("LC_ALL")) == NULL
       || strcmp (setlocale (LC_CTYPE, NULL), "C") == 0)
index b427f0992531b5b10b6a41b33596fa69ba9487a4..201ac4e76a9326c7246f00c474b86811f7ba25a5 100644 (file)
@@ -1,4 +1,4 @@
-# locale-ja.m4 serial 10
+# locale-ja.m4 serial 11
 dnl Copyright (C) 2003, 2005-2012 Free Software Foundation, Inc.
 dnl This file is free software; the Free Software Foundation
 dnl gives unlimited permission to copy and/or distribute it,
@@ -30,7 +30,7 @@ int main ()
 #if (defined _WIN32 || defined __WIN32__) && !defined __CYGWIN__
   /* On native Windows, setlocale(category, "") looks at the system settings,
      not at the environment variables.  Also, when an encoding suffix such
-     as ".65001" or ".54936" is speficied, it succeeds but sets the LC_CTYPE
+     as ".65001" or ".54936" is specified, it succeeds but sets the LC_CTYPE
      category of the locale to "C".  */
   if (setlocale (LC_ALL, getenv ("LC_ALL")) == NULL
       || strcmp (setlocale (LC_CTYPE, NULL), "C") == 0)
index 4bae6a531a9f5cbae4b2363afb4cbba006d0ab8a..26b2ba2695868697324b57fd829f23fa9e1850d1 100644 (file)
@@ -1,4 +1,4 @@
-# locale-tr.m4 serial 8
+# locale-tr.m4 serial 9
 dnl Copyright (C) 2003, 2005-2012 Free Software Foundation, Inc.
 dnl This file is free software; the Free Software Foundation
 dnl gives unlimited permission to copy and/or distribute it,
@@ -33,7 +33,7 @@ int main () {
 #if (defined _WIN32 || defined __WIN32__) && !defined __CYGWIN__
   /* On native Windows, setlocale(category, "") looks at the system settings,
      not at the environment variables.  Also, when an encoding suffix such
-     as ".65001" or ".54936" is speficied, it succeeds but sets the LC_CTYPE
+     as ".65001" or ".54936" is specified, it succeeds but sets the LC_CTYPE
      category of the locale to "C".  */
   if (setlocale (LC_ALL, getenv ("LC_ALL")) == NULL
       || strcmp (setlocale (LC_CTYPE, NULL), "C") == 0)
index de1a43b30503eb48143daf580f8e1b83e006c90f..0cf5adacc466df3627a1e2f894f319cd4321acb7 100644 (file)
@@ -1,4 +1,4 @@
-# locale-zh.m4 serial 10
+# locale-zh.m4 serial 11
 dnl Copyright (C) 2003, 2005-2012 Free Software Foundation, Inc.
 dnl This file is free software; the Free Software Foundation
 dnl gives unlimited permission to copy and/or distribute it,
@@ -31,7 +31,7 @@ int main ()
 #if (defined _WIN32 || defined __WIN32__) && !defined __CYGWIN__
   /* On native Windows, setlocale(category, "") looks at the system settings,
      not at the environment variables.  Also, when an encoding suffix such
-     as ".65001" or ".54936" is speficied, it succeeds but sets the LC_CTYPE
+     as ".65001" or ".54936" is specified, it succeeds but sets the LC_CTYPE
      category of the locale to "C".  */
   if (setlocale (LC_ALL, getenv ("LC_ALL")) == NULL
       || strcmp (setlocale (LC_CTYPE, NULL), "C") == 0)
index 6bf122a2458b01e1c043a6fee43d2377ae8bef61..05d8f7be47eeb9414a49875be0d2f07d09076d89 100644 (file)
--- a/m4/po.m4
+++ b/m4/po.m4
@@ -1,4 +1,4 @@
-# po.m4 serial 17a
+# po.m4 serial 17b
 dnl Copyright (C) 1995-2012 Free Software Foundation, Inc.
 dnl This file is free software; the Free Software Foundation
 dnl gives unlimited permission to copy and/or distribute it,
@@ -130,12 +130,12 @@ changequote([,])dnl
               test -n "$as_me" && echo "$as_me: setting ALL_LINGUAS in configure.in is obsolete" || echo "setting ALL_LINGUAS in configure.in is obsolete"
             fi
             ALL_LINGUAS_=`sed -e "/^#/d" -e "s/#.*//" "$ac_given_srcdir/$ac_dir/LINGUAS"`
-            # Hide the ALL_LINGUAS assigment from automake < 1.5.
+            # Hide the ALL_LINGUAS assignment from automake < 1.5.
             eval 'ALL_LINGUAS''=$ALL_LINGUAS_'
             POMAKEFILEDEPS="$POMAKEFILEDEPS LINGUAS"
           else
             # The set of available languages was given in configure.in.
-            # Hide the ALL_LINGUAS assigment from automake < 1.5.
+            # Hide the ALL_LINGUAS assignment from automake < 1.5.
             eval 'ALL_LINGUAS''=$OBSOLETE_ALL_LINGUAS'
           fi
           # Compute POFILES
@@ -317,7 +317,7 @@ changequote([,])dnl
     sed_x_LINGUAS=`$gt_echo "$sed_x_variable" | sed -e '/^ *#/d' -e 's/VARIABLE/LINGUAS/g'`
     ALL_LINGUAS_=`sed -n -e "$sed_x_LINGUAS" < "$ac_file"`
   fi
-  # Hide the ALL_LINGUAS assigment from automake < 1.5.
+  # Hide the ALL_LINGUAS assignment from automake < 1.5.
   eval 'ALL_LINGUAS''=$ALL_LINGUAS_'
   # Compute POFILES
   # as      $(foreach lang, $(ALL_LINGUAS), $(srcdir)/$(lang).po)
index bd245e63586734f950cca36d0026eee80fa27129..903886dc5ce53292fc702a10b8959172b48e09ca 100644 (file)
@@ -1,4 +1,4 @@
-# readline.m4 serial 9
+# readline.m4 serial 10
 dnl Copyright (C) 2005-2006, 2009-2012 Free Software Foundation, Inc.
 dnl This file is free software; the Free Software Foundation
 dnl gives unlimited permission to copy and/or distribute it,
@@ -29,7 +29,7 @@ AC_DEFUN([gl_FUNC_READLINE],
     am_save_LIBS="$LIBS"
     dnl On some systems, -lreadline doesn't link without an additional
     dnl -lncurses or -ltermcap.
-    dnl Try -lncurses before -ltermcap, because libtermcap is unsecure
+    dnl Try -lncurses before -ltermcap, because libtermcap is insecure
     dnl by design and obsolete since 1994. Try -lcurses last, because
     dnl libcurses is unusable on some old Unices.
     for extra_lib in "" ncurses termcap curses; do
index 6ba4d00cd4b7e3ed16ac3683e449a98e648bba62..acda35681bac05af7b154fa1d6d67432e2b82d70 100644 (file)
@@ -1,4 +1,4 @@
-# sig_atomic_t.m4 serial 2
+# sig_atomic_t.m4 serial 3
 dnl Copyright (C) 2003, 2009-2012 Free Software Foundation, Inc.
 dnl This file is free software; the Free Software Foundation
 dnl gives unlimited permission to copy and/or distribute it,
@@ -9,6 +9,6 @@ AC_DEFUN([gt_TYPE_SIG_ATOMIC_T],
   AC_CHECK_TYPES([sig_atomic_t], ,
     [AC_DEFINE([sig_atomic_t], [int],
        [Define as an integer type suitable for memory locations that can be
-        accessed atomically even in the presence of asynchnonous signals.])],
+        accessed atomically even in the presence of asynchronous signals.])],
     [#include <signal.h>])
 ])
index 61fe49928b4e525ae447b3cd9766420ed181062a..0ce11da13b5367e60b0b56d3d06576cb39e17f39 100644 (file)
@@ -1,4 +1,4 @@
-# vasnprintf.m4 serial 34
+# vasnprintf.m4 serial 35
 dnl Copyright (C) 2002-2004, 2006-2012 Free Software Foundation, Inc.
 dnl This file is free software; the Free Software Foundation
 dnl gives unlimited permission to copy and/or distribute it,
@@ -29,7 +29,7 @@ AC_DEFUN([gl_REPLACE_VASNPRINTF],
   gl_PREREQ_ASNPRINTF
 ])
 
-# Prequisites of lib/printf-args.h, lib/printf-args.c.
+# Prerequisites of lib/printf-args.h, lib/printf-args.c.
 AC_DEFUN([gl_PREREQ_PRINTF_ARGS],
 [
   AC_REQUIRE([AC_TYPE_LONG_LONG_INT])
@@ -37,7 +37,7 @@ AC_DEFUN([gl_PREREQ_PRINTF_ARGS],
   AC_REQUIRE([gt_TYPE_WINT_T])
 ])
 
-# Prequisites of lib/printf-parse.h, lib/printf-parse.c.
+# Prerequisites of lib/printf-parse.h, lib/printf-parse.c.
 AC_DEFUN([gl_PREREQ_PRINTF_PARSE],
 [
   AC_REQUIRE([gl_FEATURES_H])
index 27b792969ca7bab91cfa1fbc08f6e557483eb027..9c5e851f74359642206983dbe3b64c6158ffff91 100755 (executable)
@@ -6,7 +6,7 @@ echo Hello world > in.tmp
 echo world > xout.tmp
 
 fail=0
-# Test with seekable stdin; followon process must see remaining data
+# Test with seekable stdin; follow-on process must see remaining data
 (test-closein; cat) < in.tmp > out1.tmp || fail=1
 cmp out1.tmp in.tmp || fail=1
 
index 06bb3df6ec28142a8fd75089a6f885a42835327d..5cada7d970359bb233c0f141b4ac9287b3b37cec 100644 (file)
@@ -495,7 +495,7 @@ test_once (void)
   for (repeat = 0; repeat <= REPEAT_COUNT; repeat++)
     {
       /* Wait until every thread is ready.  */
-      dbgprintf ("Main thread before synchonizing for round %d\n", repeat);
+      dbgprintf ("Main thread before synchronizing for round %d\n", repeat);
       for (;;)
         {
           int ready_count = 0;
@@ -509,7 +509,7 @@ test_once (void)
             break;
           yield ();
         }
-      dbgprintf ("Main thread after  synchonizing for round %d\n", repeat);
+      dbgprintf ("Main thread after  synchronizing for round %d\n", repeat);
 
       if (repeat > 0)
         {
index a40c07923cf49ff4472af214c51cdde1114793bd..14673f2083e68aad3e63f59dafff9d090421f0d4 100644 (file)
@@ -64,7 +64,7 @@ main (void)
   ASSERT (strstr (str, "ndefined") == NULL);
 
   /* POSIX requires strerror to produce a non-NULL result for all
-     inputs; as an extension, we also guarantee a non-empty reseult.
+     inputs; as an extension, we also guarantee a non-empty result.
      Reporting EINVAL is optional.  */
   errno = 0;
   str = strerror (-3);
index 7e955cdc1d902f514239267e55cc6d840675928e..a2de3d9a8e2fe08d90c1a62656a97ffcd0bec03c 100644 (file)
@@ -75,7 +75,7 @@ static int error = 0;
 /* The keys we add to the tree.  */
 static int x[SIZE];
 
-/* Pointers into the key array, possibly permutated, to define an order
+/* Pointers into the key array, possibly permuted, to define an order
    for insertion/removal.  */
 static int y[SIZE];
 
index 5e5ed407f526b44d71e045a6061992df82fd70cf..9d195413cfe30bba680da4e603fffa1197684a5b 100755 (executable)
@@ -14,7 +14,7 @@ else
   cr='\r'
 fi
 
-# Test with seekable stdin; the followon process must see remaining data.
+# Test with seekable stdin; the follow-on process must see remaining data.
 tr @ '\177' <<EOF > in.tmp
 nnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnn - entire line consumed
 y@n - backspace does not change result
--- a/lib/des.c
+++ b/lib/des.c
@@ -64,7 +64,7 @@
  *     // Encrypt the plaintext
  *     des_ecb_encrypt(&context, plaintext, ciphertext);
  *
- *     // To recover the orginal plaintext from ciphertext use:
+ *     // To recover the original plaintext from ciphertext use:
  *     des_ecb_decrypt(&context, ciphertext, recoverd);
  *
  *
index 30a61798d5f04ccfc730356c0e99f5033d8ff08d..c7533afed28cc2c4d8eb5e64e8a4a8956d1e9be7 100644 (file)
@@ -94,9 +94,9 @@ const char diacrit_base[256] =
 
 /*------------------------------------------------------------------------.
 | For each alphabetic character, returns a code of what its diacritic is, |
-| according to the following codes: 1 (eE) over aA for latin diphtongs; 2 |
-| (') acute accent; 3 (`) grave accent; 4 (^) circumflex accent; 5 (")    |
-| umlaut or diaraesis; 6 (~) tilda; 7 (,) cedilla; 8 (o) covering degree  |
+| according to the following codes: 1 (eE) over aA for latin diphthongs;  |
+| 2 (') acute accent; 3 (`) grave accent; 4 (^) circumflex accent; 5 (")  |
+| umlaut or diaeresis; 6 (~) tilda; 7 (,) cedilla; 8 (o) covering degree  |
 | symbol; 9 (|) slashed character.                                        |
 `------------------------------------------------------------------------*/
 
index 7dbb0d3d52ebae276a1e1db2f1c6ac2c660cb83f..c70f445aeb2f51af0a20c0cca989f4039c871107 100644 (file)
@@ -36,7 +36,7 @@ expl (long double x)
 # include <float.h>
 
 static const long double C[] = {
-/* Chebyshev polynom coeficients for (exp(x)-1)/x */
+/* Chebyshev polynomial coefficients for (exp(x)-1)/x */
 # define P1 C[0]
 # define P2 C[1]
 # define P3 C[2]
index b6134bd13db3b0cbeeed00268f825ca9806d46a1..6f15a246546923c346fee30e6cef034868f9f4f2 100644 (file)
@@ -42,7 +42,7 @@
   (HAVE_WCTYPE_H && HAVE_BTOWC && HAVE_ISWCTYPE \
    && HAVE_WMEMCHR && (HAVE_WMEMCPY || HAVE_WMEMPCPY))
 
/* For platform which support the ISO C amendement 1 functionality we
    support user defined character classes.  */
 #if defined _LIBC || WIDE_CHAR_SUPPORT
 # include <wctype.h>
@@ -92,7 +92,7 @@ extern int fnmatch (const char *pattern, const char *string, int flags);
 
 # if defined _LIBC || WIDE_CHAR_SUPPORT
 /* The GNU C library provides support for user-defined character classes
-   and the functions from ISO C amendement 1.  */
+   and the functions from ISO C amendment 1.  */
 #  ifdef CHARCLASS_NAME_MAX
 #   define CHAR_CLASS_MAX_LENGTH CHARCLASS_NAME_MAX
 #  else
index 7b14f37cc92fa1ac97281975c0198181390eb1e0..50f5794fdbd38f0c63726609a6a139b24e7bb22e 100644 (file)
@@ -382,7 +382,7 @@ FCT (const CHAR *pattern, const CHAR *string, const CHAR *string_end,
                           {
                             /* We found a table entry.  Now see whether the
                                character we are currently at has the same
-                               equivalance class value.  */
+                               equivalence class value.  */
                             int len = weights[idx & 0xffffff];
                             int32_t idx2;
                             const UCHAR *np = (const UCHAR *) n;
@@ -42,7 +42,7 @@
    && HAVE_WMEMCHR && (HAVE_WMEMCPY || HAVE_WMEMPCPY))
 
-/* For platform which support the ISO C amendement 1 functionality we
+/* For platform which support the ISO C amendment 1 functionality we
    support user defined character classes.  */
 #if defined _LIBC || WIDE_CHAR_SUPPORT
index f14cf648c2fe748b7c6f07b524d7f0cfb824dc3d..42c8067708beeee4b5685215c6aae12367584e92 100644 (file)